#
# spec file for package qore-mysql-module
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qore_version 1.0.10
%define src_name module-mysql-release-%{qore_version}
%define module_api %(qore --latest-module-api 2>/dev/null)
Name:           qore-mysql-module
Version:        2.0.2.1+qore%{qore_version}
Release:        bp154.1.19
Summary:        MySQL DBI module for Qore
License:        LGPL-2.1-or-later OR GPL-2.0-or-later
Group:          Development/Languages/Other
Url:            https://qore.org
Source:         https://github.com/qorelanguage/module-mysql/archive/release-%{qore_version}/%{src_name}.tar.gz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libmysqlclient-devel
BuildRequires:  qore
BuildRequires:  qore-devel >= %{qore_version}
Requires:       %{_bindir}/env
Requires:       qore-module(abi)%{?_isa} = %{module_api}

%description
MySQL DBI driver module for the Qore Programming Language. The MySQL driver is
character set aware and supports multithreading, transaction management, and
stored procedure execution.

%package doc
Summary:        MySQL DBI module for Qore
Group:          Development/Languages/Other
BuildArch:      noarch

%description doc
MySQL module for the Qore Programming Language.

This package provides API documentation, and example programs

%prep
%setup -q -n %{src_name}

%build
%cmake
%make_build docs

%install
%cmake_install
%fdupes -s %{__builddir}/html

%files
%license COPYING.GPL COPYING.LGPL
%doc README RELEASE-NOTES AUTHORS
%{_libdir}/qore-modules

%files doc
%doc %{__builddir}/html

%changelog
* Thu Oct 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.0.2.1 for qore 1.0.10
  * Use supported APIs for string operations
* Sat Jun 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.0.2.1 for qore 0.9.15
  * Fixed selectRow() to properly report errors in fetching data
  * Implemented support for the collation option for mysql
  * Updated to QoreValue API
  * Minor bugfixes
* Sat Dec 19 2020 sarah.kriesch@opensuse.org
- add s390x in spec file
* Fri Jun 29 2018 guillaume.gardet@opensuse.org
- Update to 2.0.2.1 (fix aarch64 build):
  * New Features and Bug Fixes
  - updated SQLStatement::fetchColumns() to return an empty hash when no data is available (issue 1241)
  - fixed a bug where DBI-SELECT-ROW-ERROR exceptions were being raised as MYSQL-SELECT-ROW-ERROR exceptions (issue 2542)
  * Update from 2.0.2:
  - fixed formatting bugs in invalid value specification error messages
  - updated configure to find and compile with MariaDB and Percona includes and libs
  - placeholders and quotes in SQL comments are ignored
  - fixed time column retrieval; the date component is now set to 1970-01-01
  - fixed binary and varbinary column handling
  - fixed the "optimal-numbers" option with decimal values with decimal points (issue 542)
  - fixed returning result sets with duplicate column names (issue 832)
- Switch source URL to github
- Add aarch64 as 64-bit arch in spec file
* Mon Aug 31 2015 normand@linux.vnet.ibm.com
- add ppc64le as 64 bit architecture in spec file
* Thu Aug 21 2014 petr@yarpen.cz
- fixed license in spec file. GPL-2.0+ used only
* Fri Aug 15 2014 petr@yarpen.cz
- migrated to OBS file layout
